@@ -2,8 +2,8 @@
 export PATH='/usr/lib/distcc/bin:/usr/local/sbin:/usr/local/bin:/usr/bin:/usr/bin/site_perl:/usr/bin/vendor_perl:/usr/bin/core_perl'
 echo 'name: charset
 version: 0.3.7.1
-id: charset-0.3.7.1-07fa1295548c21364abbf3188fa2df38
-key: chars_68hDqbOXOtH3ywWm3VlaWR
+id: charset-0.3.7.1-eb9c9b19f9448bfb51c91765226aa73d
+key: chars_0opeI6HOvWU8FUZilER5sS
 license: BSD3
 copyright: (c) Edward Kmett 2010-2012
 maintainer: ekmett@gmail.com
@@ -24,14 +24,14 @@ trusted: False
 import-dirs: /usr/lib/ghc-7.10.3/site-local/charset-0.3.7.1
 library-dirs: /usr/lib/ghc-7.10.3/site-local/charset-0.3.7.1
 data-dir: /usr/share/arm-linux-ghc-7.10.3/charset-0.3.7.1
-hs-libraries: HScharset-0.3.7.1-68hDqbOXOtH3ywWm3VlaWR
+hs-libraries: HScharset-0.3.7.1-0opeI6HOvWU8FUZilER5sS
 depends:
     array-0.5.1.0-a4b4f31b03b7779670557ea46745a386
     base-4.8.2.0-2f1f71a7fcf013cd47fd21f489064f9a
     bytestring-0.10.6.0-3b51e35daa3fe2a56ecd3687fb389cdc
     containers-0.5.6.2-169e53288f333dd2f0207994fd53822f
-    semigroups-0.18.1-4a4dee25d838ab8c8d38a0caa045cf78
-    unordered-containers-0.2.7.0-03f1d2fb96e30aca19bb1467e9476c22
+    semigroups-0.18.1-30b269dfd15f1b13a72c07aebe8ef1de
+    unordered-containers-0.2.7.0-d91279dcd5fa13d7f88095dc08e2fda6
 haddock-interfaces: /usr/share/doc/haskell-charset/html/charset.haddock
 haddock-html: /usr/share/doc/haskell-charset/html
 ' | '/usr/bin/ghc-pkg' 'update' '-' '--global' '--no-user-package-db' "$@"
